"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
from typing import Any, Dict
from typing_extensions import TypedDict


class StepsOverridesTypedDict(TypedDict):
    providers: Dict[str, Dict[str, Any]]
    r"""Passing the provider id and the provider specific configurations"""


class StepsOverrides(BaseModel):
    providers: Dict[str, Dict[str, Any]]
    r"""Passing the provider id and the provider specific configurations"""
