"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .deletetopicsubscriptionsrequestdto import (
    DeleteTopicSubscriptionsRequestDto,
    DeleteTopicSubscriptionsRequestDtoTypedDict,
)
from .deletetopicsubscriptionsresponsedto import (
    DeleteTopicSubscriptionsResponseDto,
    DeleteTopicSubscriptionsResponseDtoTypedDict,
)
from novu_py.types import BaseModel
from novu_py.utils import (
    FieldMetadata,
    HeaderMetadata,
    PathParamMetadata,
    RequestMetadata,
)
import pydantic
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TopicsControllerDeleteTopicSubscriptionsRequestTypedDict(TypedDict):
    topic_key: str
    r"""The key identifier of the topic"""
    delete_topic_subscriptions_request_dto: DeleteTopicSubscriptionsRequestDtoTypedDict
    idempotency_key: NotRequired[str]
    r"""A header for idempotency purposes"""


class TopicsControllerDeleteTopicSubscriptionsRequest(BaseModel):
    topic_key: Annotated[
        str,
        pydantic.Field(alias="topicKey"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""The key identifier of the topic"""

    delete_topic_subscriptions_request_dto: Annotated[
        DeleteTopicSubscriptionsRequestDto,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    idempotency_key: Annotated[
        Optional[str],
        pydantic.Field(alias="idempotency-key"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""A header for idempotency purposes"""


class TopicsControllerDeleteTopicSubscriptionsResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: DeleteTopicSubscriptionsResponseDtoTypedDict


class TopicsControllerDeleteTopicSubscriptionsResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: DeleteTopicSubscriptionsResponseDto
