"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from novu_py.types import BaseModel
import pydantic
from typing import List
from typing_extensions import Annotated, TypedDict


class CreateTopicSubscriptionsRequestDtoTypedDict(TypedDict):
    subscriber_ids: List[str]
    r"""List of subscriber identifiers to subscribe to the topic (max: 100)"""


class CreateTopicSubscriptionsRequestDto(BaseModel):
    subscriber_ids: Annotated[List[str], pydantic.Field(alias="subscriberIds")]
    r"""List of subscriber identifiers to subscribe to the topic (max: 100)"""
